==> 1.0.0.zip: terraform-provider-dynamix/samples/cloudapi/k8s/data_k8ci_list/main.tf <==
/*
Пример использования
Получение информации о k8ci
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    dynamix = {
      source  = "basistech.ru/tf/dynamix"
      version = "<VERSION>"
    }
  }
}
*/


provider "dynamix" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "dynamix_k8ci_list" "k8ci_list" {
  #поиск по ID
  #опциональный параметр
  #тип - целое число
  by_id = 12

  #поиск по наименованию
  #опциональный параметр
  #тип - строка
  name = "name"

  #поиск по статус
  #опциональный параметр
  #тип - строка
  status = "status"

  #поиск по worker драйверу
  #опциональный параметр
  #тип - строка
  worker_driver = "wdriver"

  #поиск по master драйверу
  #опциональный параметр
  #тип - строка
  master_driver = "wdriver"

  #поиск по network плагину
  #опциональный параметр
  #тип - строка
  network_plugin = "flannel"

  #показать выключенные K8CI
  #опциональный параметр
  #тип - булев
  include_disabled = true

  #сортировка по одному из поддерживаемых полей
  #опциональный параметр
  #тип - строка
  #формат - "+поле" по возрастанию / "-поле" по убыванию
  sort_by = "+name"

  #номер страницы
  #опциональный параметр
  #тип - целое число
  page = 1

  #размер страницы
  #опциональный параметр
  #тип - целое число
  size = 5
}

output "output_k8ci" {
  value = data.dynamix_k8ci_list.k8ci_list
}

==> 1.2.1.zip: terraform-provider-dynamix/samples/cloudapi/k8s/data_k8ci_list/main.tf <==
/*
Пример использования
Получение информации о k8ci
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    dynamix = {
      source  = "basistech.ru/tf/dynamix"
      version = "<VERSION>"
    }
  }
}
*/


provider "dynamix" {
  authenticator = "decs3o"
  #controller_url = <DYNAMIX_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DYNAMIX_OAUTH2_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "dynamix_k8ci_list" "k8ci_list" {
  #поиск по ID
  #опциональный параметр
  #тип - целое число
  by_id = 12

  #поиск по наименованию
  #опциональный параметр
  #тип - строка
  name = "name"

  #поиск по статус
  #опциональный параметр
  #тип - строка
  status = "status"

  #поиск по worker драйверу
  #опциональный параметр
  #тип - строка
  worker_driver = "wdriver"

  #поиск по master драйверу
  #опциональный параметр
  #тип - строка
  master_driver = "wdriver"

  #поиск по network плагину
  #опциональный параметр
  #тип - строка
  network_plugin = "flannel"

  #показать выключенные K8CI
  #опциональный параметр
  #тип - булев
  include_disabled = true

  #сортировка по одному из поддерживаемых полей
  #опциональный параметр
  #тип - строка
  #формат - "+поле" по возрастанию / "-поле" по убыванию
  sort_by = "+name"

  #номер страницы
  #опциональный параметр
  #тип - целое число
  page = 1

  #размер страницы
  #опциональный параметр
  #тип - целое число
  size = 5
}

output "output_k8ci" {
  value = data.dynamix_k8ci_list.k8ci_list
}
